Package: SpaceTrooper
Type: Package
Title: SpaceTrooper performs Quality Control analysis of Image-Based
        spatial
Version: 1.0.0
Authors@R: 
        c(person("Dario", "Righelli",
            email="dario.righelli@gmail.com",
            role=c("aut", "cre"),
            comment=c(ORCID="0000-0003-1504-3583")),
        person(given="Benedetta", family="Banzi", role="aut"),
        person(given="Oriana", family="Romano", role="ctb"),
        person(given="Matteo", family="Merchionni", role="ctb"),
        person(given="Mattia", family="Forcato", role="ctb"),
        person(given="Silvio", family="Bicciato", role="aut"),
        person(given="Davide", family="Risso", role="ctb"))
Description: SpaceTrooper performs Quality Control analysis using data driven 
    GLM models of Image-Based spatial data, providing exploration plots, 
    QC metrics computation, outlier detection.
    It implements a GLM strategy for the detection of low quality cells in 
    imaging-based spatial data (Transcriptomics and Proteomics). 
    It additionally implements several plots for the visualization of 
    imaging based polygons through the ggplot2 package.
License: MIT + file LICENSE
Encoding: UTF-8
Depends: R (>= 4.4.0), SpatialExperiment
Imports: DropletUtils, S4Vectors, SummarizedExperiment, arrow,
        data.table, dplyr, e1071, ggplot2, ggpubr, robustbase, scater,
        scuttle, sf, sfheaders, cowplot, glmnet, rhdf5, methods, rlang,
        SpatialExperimentIO
Suggests: knitr, rmarkdown, BiocStyle, testthat (>= 3.0.0), withr,
        viridis
biocViews: Software, Transcriptomics, GeneExpression, QualityControl,
        Spatial, SingleCell, DataImport, ImmunoOncology
RoxygenNote: 7.3.3
VignetteBuilder: knitr
BugReports: https://github.com/drighelli/SpaceTrooper/issues
URL: https://github.com/drighelli/SpaceTrooper
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/SpaceTrooper
git_branch: RELEASE_3_22
git_last_commit: 88c0696
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 06:38:00 UTC; biocbuild
Author: Dario Righelli [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1504-3583>),
  Benedetta Banzi [aut],
  Oriana Romano [ctb],
  Matteo Merchionni [ctb],
  Mattia Forcato [ctb],
  Silvio Bicciato [aut],
  Davide Risso [ctb]
Maintainer: Dario Righelli <dario.righelli@gmail.com>
