# Generated by roxygen2: do not edit by hand

export(.getActiveGeometryName)
export(.renameGeometry)
export(.setActiveGeometry)
export(addPolygonsToSPE)
export(checkOutliers)
export(computeAreaFromPolygons)
export(computeAspectRatioFromPolygons)
export(computeCenterFromPolygons)
export(computeLambda)
export(computeMissingMetricsMerfish)
export(computeMissingMetricsXenium)
export(computeOutliersQCScore)
export(computeQCScore)
export(computeQCScoreFlags)
export(computeSpatialOutlier)
export(computeThresholdFlags)
export(computeTrainDF)
export(getFencesOutlier)
export(getModelFormula)
export(plotCellsFovs)
export(plotCentroids)
export(plotMetricHist)
export(plotPolygons)
export(plotQScoreTerms)
export(plotZoomFovsMap)
export(qcFlagPlots)
export(readAndAddPolygonsToSPE)
export(readCosmxProteinSPE)
export(readCosmxSPE)
export(readMerfishSPE)
export(readPolygons)
export(readPolygonsCosmx)
export(readPolygonsMerfish)
export(readPolygonsXenium)
export(readXeniumSPE)
export(spatialPerCellQC)
export(trainModel)
export(updateCosmxProteinSPE)
export(updateCosmxSPE)
export(updateXeniumSPE)
import(SpatialExperiment)
importFrom(DropletUtils,read10xCounts)
importFrom(S4Vectors,'metadata<-')
importFrom(S4Vectors,DataFrame)
importFrom(S4Vectors,cbind.DataFrame)
importFrom(S4Vectors,metadata)
importFrom(SpatialExperiment,SpatialExperiment)
importFrom(SpatialExperimentIO,readCosmxSXE)
importFrom(SpatialExperimentIO,readXeniumSXE)
importFrom(SummarizedExperiment,assays)
importFrom(SummarizedExperiment,colData)
importFrom(SummarizedExperiment,rowData)
importFrom(arrow,read_parquet)
importFrom(cowplot,get_legend)
importFrom(cowplot,plot_grid)
importFrom(data.table,fread)
importFrom(data.table,merge.data.table)
importFrom(dplyr,case_when)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,pull)
importFrom(dplyr,select)
importFrom(dplyr,ungroup)
importFrom(e1071,skewness)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,annotate)
importFrom(ggplot2,coord_fixed)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_sf)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,margin)
importFrom(ggplot2,scale_color_gradient)
importFrom(ggplot2,scale_color_gradientn)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_colour_manual)
importFrom(ggplot2,scale_fill_identity)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_fill_viridis_c)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_minimal)
importFrom(ggplot2,theme_void)
importFrom(ggpubr,annotate_figure)
importFrom(ggpubr,ggarrange)
importFrom(glmnet,cv.glmnet)
importFrom(glmnet,glmnet)
importFrom(grDevices,colors)
importFrom(methods,is)
importFrom(rhdf5,h5dump)
importFrom(rlang,.data)
importFrom(robustbase,adjbox)
importFrom(robustbase,mc)
importFrom(scater,addPerCellQC)
importFrom(scater,plotColData)
importFrom(scuttle,isOutlier)
importFrom(scuttle,outlier.filter)
importFrom(sf,st_as_sf)
importFrom(sf,st_buffer)
importFrom(sf,st_cast)
importFrom(sf,st_geometry)
importFrom(sf,st_geometry_type)
importFrom(sf,st_is_valid)
importFrom(sf,st_polygon)
importFrom(sf,st_sf)
importFrom(sf,st_sfc)
importFrom(sfheaders,sf_polygon)
importFrom(stats,as.formula)
importFrom(stats,model.matrix)
importFrom(stats,predict)
importFrom(stats,quantile)
